# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    
    # Järva (county)
    p.county("Järva", "")
    p.municipality("Türi", "")
    p.smallborough("Särevere", "")
    p.smallborough("Oisu", "")
    p.village("Lokuta", "")
    p.village("Jändja", "")
    p.village("Kabala", "")
    p.village("Türi-Alliku", "")
    p.village("Poaka", "")
    p.village("Karjaküla", "72242")
    p.village("Rikassaare", "72307")
    p.village("Väljaotsa", "72311")
    p.village("Villevere", "72006")
    p.village("Kirna", "72231")
    p.village("Rassi", "72007")
    p.village("Raukla", "72305")
    p.village("Laupa", "72102")
    p.village("Saareotsa", "72308")
    p.village("Tännassilma", "72310")
    p.village("Pibari", "72005")
    p.village("Pala", "72234")
    p.village("Kurla", "72009")
    p.village("Ollepa", "72002")
    p.village("Äiamaa", "72312")
    p.village("Vilita", "72245")
    p.village("Retla", "72306")
    p.village("Sagevere", "72003")
    p.village("Arkma", "72011")
    p.village("Änari", "72241")
    p.village("Metsaküla", "72303")
    p.village("Põikva", "72244")
    p.village("Kärevere", "72302")
    p.village("Tori", "72230")
    p.village("Taikse", "72309")
    p.village("Meossaare", "72010")
    p.village("Näsuvere", "72246")

    p.municipality("Roosna-Alliku", "")
    p.village("Viisu", "")
    p.village("Valasti", "73210")
    p.village("Kihme", "73206")
    p.village("Koordi", "73212")
    p.village("Oeti", "73208")
    p.village("Kodasema", "73207")
    p.village("Kirisaare", "73211")
    p.village("Kaaruka", "73205")
    p.village("Tännapere", "73209")
    p.village("Allikjärve", "73203")
    p.village("Vedruka", "73213")

    p.town("Paide", "")
    p.village("Tarbja", "")
    p.village("Kriilevälja", "")
    p.village("Sargvere", "")
    p.village("Sillaotsa", "")
    p.village("Sõmeru", "72614")
    p.village("Viraksaare", "")
    p.village("Veskiaru", "72760")
    p.village("Mustla", "72607")
    p.village("Ojaküla", "72610")
    p.village("Mustla-Nõmme", "72608")
    p.village("Eivere", "72757")
    p.village("Mäeküla", "")
    p.village("Korba", "72753")
    p.village("Valgma", "72606")
    p.village("Võõbu", "72615")
    p.village("Kirila", "72755")
    p.village("Mündi", "72762")
    p.village("Seinapalu", "72761")
    p.village("Otiku", "72611")
    p.village("Nurme", "72609")
    p.village("Prääma", "72763")
    p.village("Nurmsi", "72603")
    p.village("Purdi", "72613")
    p.village("Mäo", "72751")
    p.village("Suurpalu", "72605")
    p.village("Anna", "72601")
    p.village("Pikaküla", "72756")

    p.municipality("Väätsa", "")
    p.village("Aasuvälja", "")
    p.village("Reopalu", "")
    p.village("Ülejõe", "")
    p.village("Lõõla", "72814")
    p.village("Roovere", "72805")
    p.village("Vissuvere", "72812")
    p.village("Väljataguse", "72802")
    p.village("Saueaugu", "72813")
    p.village("Röa", "72806")
    p.village("Piiumetsa", "72804")

    p.municipality("Ambla", "")
    p.smallborough("Aravete", "")
    p.smallborough("Käravete", "")
    p.village("Raka", "")
    p.village("Kurisoo", "")
    p.village("Jõgisoo", "")
    p.village("Roosna", "")
    p.village("Märjandi", "73513")
    p.village("Sääsküla", "73511")
    p.village("Kukevere", "73512")
    p.village("Mägise", "73510")
    p.village("Reinevere", "73507")
    p.village("Rava", "73506")

    p.municipality("Järva-Jaani", "")
    p.village("Karinu", "")
    p.village("Metsla", "73307")
    p.village("Kuksema", "73306")
    p.village("Jalalõpe", "73303")
    p.village("Jalgsema", "73304")
    p.village("Kagavere", "73305")
    p.village("Seliküla", "73310")
    p.village("Metstaguse", "73308")
    p.village("Ramma", "73309")

    p.municipality("Koeru", "")
    p.village("Ervita", "")
    p.village("Vao", "")
    p.village("Rõhu", "73018")
    p.village("Udeva", "73019")
    p.village("Tammiku", "73023")
    p.village("Preedi", "73017")
    p.village("Norra", "73016")
    p.village("Kuusna", "73008")
    p.village("Visusti", "73012")
    p.village("Valila", "73024")
    p.village("Tudre", "73010")
    p.village("Väinjärve", "73021")
    p.village("Santovi", "73005")
    p.village("Koidu-Ellavere", "73027")
    p.village("Vahuküla", "73020")
    p.village("Aruküla", "73004")
    p.village("Jõeküla", "73014")
    p.village("Kalitsa", "73022")
    p.village("Liusvere", "73015")
    p.village("Kapu", "73007")
    p.village("Puhmu", "73006")
    p.village("Laaneotsa", "73013")
    p.village("Salutaguse", "73009")
    p.village("Vuti", "73011")
    p.village("Merja", "73026")
    p.village("Abaja", "73025")

    p.municipality("Kareda", "")
    p.village("Esna", "")
    p.smallborough("Peetri", "")
    p.village("Õle", "73108")
    p.village("Köisi", "73104")
    p.village("Ataste", "73103")
    p.village("Müüsleri", "73105")
    p.village("Vodja", "73111")
    p.village("Küti", "73106")
    p.village("Ämbra", "73110")
    p.village("Ammuta", "73107")
    p.village("Öötla", "73112")

    p.municipality("Albu", "")
    p.village("Pullevere", "")
    p.village("Järva-Madise", "")
    p.village("Ahula", "")
    p.village("Seidla", "73407")
    p.village("Vetepere", "73416")
    p.village("Ageri", "73408")
    p.village("Soosalu", "73414")
    p.village("Mägede", "73412")
    p.village("Orgmetsa", "73405")
    p.village("Sugalepa", "73415")
    p.village("Kaalepi", "73403")
    p.village("Lehtmetsa", "73410")
    p.village("Mõnuvere", "73411")
    p.village("Neitla", "73404")
    p.village("Peedu", "73413")

    p.municipality("Imavere", "")
    p.village("Käsukonna", "")
    p.village("Taadikvere", "")
    p.village("Jalametsa", "72403")
    p.village("Võrevere", "72409")
    p.village("Eistvere", "72402")
    p.village("Laimetsa", "72410")
    p.village("Kiigevere", "72405")
    p.village("Pällastvere", "72412")
    p.village("Puiatu", "")
    p.village("Järavere", "72404")
    p.village("Tammeküla", "72411")

    p.municipality("Koigi", "")
    p.village("Päinurme", "")
    p.village("Huuksi", "72503")
    p.village("Vaali", "72513")
    p.village("Tamsi", "72509")
    p.village("Lähevere", "72511")
    p.village("Silmsi", "72507")
    p.village("Sõrandu", "72508")
    p.village("Keri", "72505")
    p.village("Väike-Kareda", "72510")
    p.village("Prandi", "72506")
    p.village("Kahala", "")
    p.village("Rutikvere", "72512")

    p.municipality("Kolu", "")




# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Põlva (county)
    p.county("Põlva", "")
    p.town("Räpina", "")
    p.village("Ristipalo", "")
    p.village("Ruusa", "")
    p.village("Leevaku", "")
    p.village("Linte", "")
    p.village("Naha", "64411")
    p.village("Kõnnu", "64407")
    p.village("Võiardi", "64426")
    p.village("Saareküla", "64419")
    p.village("Tsirksi", "64425")
    p.village("Sillapää", "64420")
    p.village("Köstrimäe", "64408")
    p.village("Toolamaa", "64423")
    p.village("Võuküla", "64427")
    p.village("Mägiotsa", "64410")
    p.village("Nulga", "64412")
    p.village("Pindi", "64413")
    p.village("Kassilaane", "64406")
    p.village("Raigla", "64417")
    p.village("Tooste", "64424")
    p.village("Meelva", "64409")
    p.village("Jaanikeste", "64405")
    p.village("Rahumäe", "64416")
    p.village("Pääsna", "64414")
    p.village("Sülgoja", "64422")
    p.village("Raadama", "64415")
    p.village("Suure-Veerksu", "64421")

    p.town("Põlva", "")
    p.village("Soesaare", "")
    p.village("Rosma", "")
    p.village("Himmaste", "")
    p.village("Taevaskoja", "")
    p.village("Mammaste", "")
    p.village("Tromsi", "63223")
    p.village("Adiste", "63204")
    p.village("Valgesoo", "63226")
    p.village("Vanaküla", "63227")
    p.village("Metste", "63213")
    p.village("Nooritsmetsa", "63215")
    p.village("Peri", "63218")
    p.village("Holvandi", "63207")
    p.village("Puskaru", "63219")
    p.village("Meemaste", "63212")
    p.village("Eoste", "63206")
    p.village("Puuri", "63220")
    p.village("Kähri", "63209")
    p.village("Orajõe", "63216")
    p.village("Aarna", "63203")
    p.village("Lutsu", "63210")
    p.village("Tännassilma", "63224")
    p.village("Kiuma", "")
    p.village("Uibujärve", "63225")
    p.village("Miiaste", "63214")
    p.village("Partsi", "63217")
    p.village("Andre", "63205")

    p.municipality("Veriora", "")
    p.village("Leevi", "")
    p.village("Männisalu", "64215")
    p.village("Viira", "64224")
    p.village("Kullamäe", "64210")
    p.village("Haavapää", "64203")
    p.village("Nohipalo", "64216")
    p.village("Koolmajärve", "64209")
    p.village("Kunksilla", "64211")
    p.village("Laho", "")
    p.village("Süvahavva", "64220")
    p.village("Soohara", "64219")
    p.village("Timo", "64221")
    p.village("Sarvemäe", "64218")
    p.village("Vareste", "64222")
    p.village("Kikka", "64206")
    p.village("Lihtensteini", "64213")
    p.village("Väike-Veerksu", "64228")
    p.village("Kirmsi", "64207")
    p.village("Vändra", "64229")
    p.village("Võika", "64227")
    p.village("Jõeveere", "64233")
    p.village("Himmiste", "64204")
    p.village("Viluste", "64225")
    p.village("Mõtsavaara", "64214")
    p.village("Koolma", "64208")
    p.village("Vinso", "64226")
    p.village("Pahtpää", "64217")
    p.village("Jõevaara", "64205")
    p.village("Verioramõisa", "64223")

    p.municipality("Kanepi", "")
    p.village("Põlgaste", "")
    p.village("Magari", "")
    p.village("Jõgehara", "63109")
    p.village("Peetrimõisa", "63118")
    p.village("Kooraste", "63114")
    p.village("Sõreste", "63121")
    p.village("Lauri", "63115")
    p.village("Soodoma", "63124")
    p.village("Jõksi", "63110")
    p.village("Heisri", "63106")
    p.village("Koigera", "63113")
    p.village("Hino", "63107")
    p.village("Rebaste", "63120")
    p.village("Kaagvere", "63103")
    p.village("Närapää", "63117")
    p.village("Erastvere", "63105")
    p.village("Piigandi", "63119")
    p.village("Kaagna", "63111")
    p.village("Hurmi", "63108")
    p.village("Varbuse", "63122")
    p.village("Karste", "63112")

    p.municipality("Ahja", "")
    p.village("Ibaste", "63703")
    p.village("Akste", "63702")
    p.village("Mõtsküla", "63708")
    p.village("Vanamõisa", "63709")
    p.village("Kosova", "63704")
    p.village("Mustakurmu", "63707")
    p.village("Loko", "63706")
    p.village("Kärsa", "63705")

    p.municipality("Kõlleste", "")
    p.village("Krootuse", "")
    p.village("Prangli", "")
    p.village("Veski", "63511")
    p.village("Häätaru", "63502")
    p.village("Tõdu", "63510")
    p.village("Karaski", "63504")
    p.village("Voorepalu", "63512")
    p.village("Piigaste", "63507")
    p.village("Palutaja", "63506")
    p.village("Tuulemäe", "63509")
    p.village("Ihamaru", "63503")

    p.municipality("Vastse-Kuuste", "")
    p.village("Vooreküla", "")
    p.village("Karilatsi", "")
    p.village("Valgemetsa", "63610")
    p.village("Kiidjärve", "63604")
    p.village("Koorvere", "63605")
    p.village("Logina", "63607")
    p.village("Padari", "63609")
    p.village("Lootvina", "63608")
    p.village("Leevijõe", "63606")

    p.municipality("Värska", "")
    p.village("Lobotka", "")
    p.village("Tonja", "64025")
    p.village("Popovitsa", "64019")
    p.village("Rääptsova", "64020")
    p.village("Velna", "64030")
    p.village("Õrsava", "64035")
    p.village("Väike-Rõsna", "64034")
    p.village("Podmotsa", "64018")
    p.village("Verhulitsa", "64031")
    p.village("Litvina", "64011")
    p.village("Korela", "64007")
    p.village("Vaartsi", "64028")
    p.village("Saatse", "64037")
    p.village("Matsuri", "64036")
    p.village("Vedernika", "64029")
    p.village("Ulitina", "64027")
    p.village("Perdaku", "64017")
    p.village("Kremessova", "64009")
    p.village("Saabolda", "64021")
    p.village("Sesniki", "64023")
    p.village("Koidula", "64004")
    p.village("Kolodavitsa", "64005")
    p.village("Kolossova", "64006")
    p.village("Lutepää", "64013")
    p.village("Pattina", "64016")
    p.village("Nedsaja", "64015")
    p.village("Säpina", "64024")
    p.village("Võpolsova", "64033")
    p.village("Kundruse", "64010")
    p.village("Voropi", "64032")
    p.village("Määsovitsa", "64014")
    p.village("Kostkova", "64008")
    p.village("Samarina", "64022")
    p.village("Treski", "64026")

    p.municipality("Mikitamäe", "")
    p.village("Võõpsu", "")
    p.village("Lüübnitsa", "")
    p.village("Beresje", "")
    p.village("Niitsiku", "64319")
    p.village("Puugnitsa", "64311")
    p.village("Rõsna", "64312")
    p.village("Igrise", "64304")
    p.village("Audjassaare", "64302")
    p.village("Järvepää", "64305")
    p.village("Usinitsa", "64316")
    p.village("Selise", "64314")
    p.village("Rääsolaane", "64313")
    p.village("Varesmäe", "64317")
    p.village("Laossina", "64308")
    p.village("Karisilla", "64307")
    p.village("Toomasmäe", "64315")

    p.municipality("Mooste", "")
    p.village("Terepi", "64613")
    p.village("Kastmekoja", "64608")
    p.village("Rasina", "64618")
    p.village("Jaanimõisa", "64604")
    p.village("Säässaare", "64612")
    p.village("Säkna", "64611")
    p.village("Kauksi", "64617")
    p.village("Viisli", "64614")
    p.village("Savimäe", "64609")
    p.village("Kanassaare", "64607")
    p.village("Kaaru", "64605")
    p.village("Kadaja", "64606")
    p.village("Suurmetsa", "64610")

    p.municipality("Orava", "")
    p.village("Piusa", "")
    p.village("Suuremetsa", "64105")
    p.village("Kliima", "64110")
    p.village("Tamme", "64106")
    p.village("Hanikase", "64107")
    p.village("Luuska", "64117")
    p.village("Praakmani", "64104")
    p.village("Kakusuu", "64109")
    p.village("Madi", "64118")
    p.village("Kõvera", "64115")
    p.village("Liinamäe", "64116")
    p.village("Korgõmõisa", "64112")
    p.village("Vivva", "64131")
    p.village("Päka", "64123")
    p.village("Jantra", "64103")
    p.village("Tuderna", "64130")
    p.village("Kahkva", "")
    p.village("Rõssa", "64127")
    p.village("Kamnitsa", "64111")
    p.village("Riihora", "64126")
    p.village("Lepassaare", "64102")
    p.village("Oro", "64121")
    p.village("Pääväkese", "64124")
    p.village("Marga", "64119")
    p.village("Kõivsaare", "64113")
    p.village("Soe", "64128")
    p.village("Soena", "64129")
    p.village("Rebasmäe", "64125")
    p.village("Kõliküla", "64114")

    p.municipality("Valgjärve", "")
    p.village("Saverna", "")
    p.village("Sirvaste", "63413")
    p.village("Abissaare", "63404")
    p.village("Hauka", "63406")
    p.village("Krüüdneri", "63408")
    p.village("Sulaoja", "63414")
    p.village("Maaritsa", "63417")
    p.village("Vissi", "63416")
    p.village("Aiaste", "63405")
    p.village("Puugi", "63412")
    p.village("Tiido", "63415")
    p.village("Pikajärve", "63410")
    p.village("Mügra", "63409")
    p.village("Kooli", "63407")
    p.village("Pikareinu", "63411")

    p.municipality("Laheda", "")
    p.village("Tilsi", "")
    p.village("Himma", "63002")
    p.village("Pragi", "63007")
    p.village("Lahe", "63004")
    p.village("Vardja", "63011")
    p.village("Mustajõe", "63005")
    p.village("Vana-Koiola", "63010")
    p.village("Roosi", "63008")
    p.village("Naruski", "63006")
    p.village("Joosu", "63003")
    p.village("Suurküla", "63009")





# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    
    # Jõgeva (county)
    p.county("Jõgeva", "")
    p.municipality("Torma", "")
    p.smallborough("Sadala", "")
    p.village("Ookatku", "48512")
    p.village("Rääbise", "48516")
    p.village("Kodismaa", "48505")
    p.village("Sätsuvere", "48517")
    p.village("Võtikvere", "48525")
    p.village("Kantküla", "48526")
    p.village("Rassiku", "48514")
    p.village("Leedi", "48508")
    p.village("Tuimõisa", "48519")
    p.village("Tähkvere", "48521")
    p.village("Võidivere", "48524")
    p.village("Vaiatu", "48522")
    p.village("Iravere", "48503")
    p.village("Kõnnu", "48507")
    p.village("Tealama", "48518")
    p.village("Tõikvere", "48520")
    p.village("Vanamõisa", "48523")
    p.village("Näduvere", "48511")
    p.village("Reastvere", "48515")
    p.village("Oti", "48513")
    p.village("Liikatku", "48509")
    p.village("Lilastvere", "48510")
    p.village("Koimula", "48506")

    p.town("Põltsamaa", "")
    p.smallborough("Adavere", "")
    p.village("Esku", "")
    p.village("Kuningamäe", "")
    p.village("Mõhküla", "")
    p.village("Lustivere", "")
    p.village("Kaavere", "48006")
    p.village("Tõrenurme", "48025")
    p.village("Väike-Kamari", "48030")
    p.village("Pilu", "48018")
    p.village("Annikvere", "48004")
    p.village("Kablaküla", "48007")
    p.village("Lebavere", "48012")
    p.village("Võhmanõmme", "48028")
    p.village("Vitsjärve", "48027")
    p.village("Rõstla", "48022")
    p.village("Kaliküla", "48008")
    p.village("Kalme", "48031")
    p.village("Umbusi", "48026")
    p.village("Neanurme", "48015")
    p.village("Mällikvere", "48014")
    p.village("Pauastvere", "48017")
    p.village("Pudivere", "48019")
    p.village("Puduküla", "48020")
    p.village("Nõmavere", "48016")
    p.village("Sulustvere", "48024")
    p.village("Puiatu", "48021")
    p.village("Võisiku", "48029")
    p.smallborough("Kamari", "48003")
    p.village("Alastvere", "48010")
    p.village("Räsna", "48023")

    p.municipality("Tabivere", "")
    p.village("Voldi", "")
    p.village("Kõduküla", "")
    p.village("Lilu", "49113")
    p.village("Sortsi", "49119")
    p.village("Kaitsemõisa", "49106")
    p.village("Kõnnujõe", "49110")
    p.village("Elistvere", "49103")
    p.village("Reinu", "49117")
    p.village("Valgma", "49123")
    p.village("Tormi", "49120")
    p.village("Õvanurme", "49125")
    p.village("Pataste", "49115")
    p.village("Otslava", "49114")
    p.village("Maarja-Magdaleena", "49126")
    p.village("Vahi", "49122")
    p.village("Kassema", "49107")
    p.village("Juula", "49104")
    p.village("Kärksi", "49112")
    p.village("Uhmardu", "49121")
    p.village("Sepa", "49118")
    p.village("Koogi", "49108")
    p.village("Kaiavere", "")
    p.village("Raigastvere", "49116")
    p.village("Kõrenduse", "49111")

    p.town("Mustvee", "")
    p.town("Jõgeva", "")
    p.smallborough("Kuremaa", "")
    p.village("Õuna", "")
    p.village("Mooritsa", "")
    p.smallborough("Laiuse", "")
    p.smallborough("Siimusti", "")
    p.village("Vana-Jõgeva", "")
    p.village("Lemuvere", "48417")
    p.village("Liivoja", "48418")
    p.village("Alavere", "48405")
    p.village("Kõola", "48414")
    p.village("Rohe", "48428")
    p.village("Viruvere", "48435")
    p.village("Painküla", "48422")
    p.village("Lõpe", "48440")
    p.village("Kaude", "48411")
    p.village("Ellakvere", "48406")
    p.village("Selli", "48429")
    p.village("Endla", "48407")
    p.village("Kaera", "48409")
    p.village("Raaduvere", "48427")
    p.village("Pedja", "48426")
    p.village("Vilina", "48434")
    p.village("Väljaotsa", "48441")
    p.village("Pakaste", "48423")
    p.village("Kurista", "48413")
    p.village("Paduvere", "48421")
    p.village("Patjala", "48425")
    p.village("Laiusevälja", "48416")
    p.village("Soomevere", "48430")
    p.village("Võduvere", "48436")
    p.village("Vaimastvere", "48446")
    p.village("Võikvere", "48437")
    p.village("Palupere", "48424")
    p.village("Kivijärve", "48412")
    p.village("Teilma", "48431")
    p.village("Tooma", "48432")
    p.village("Kassinurme", "48410")
    p.village("Kärde", "48415")
    p.village("Mõisamaa", "48420")

    p.municipality("Palamuse", "")
    p.village("Ehavere", "49205")
    p.village("Süvalepa", "49219")
    p.village("Eerikvere", "49204")
    p.village("Imukvere", "49206")
    p.village("Sudiste", "49218")
    p.village("Pikkjärve", "49213")
    p.village("Kudina", "49210")
    p.village("Järvepera", "49207")
    p.village("Visusti", "49224")
    p.village("Mullavere", "49211")
    p.village("Ronivere", "49217")
    p.village("Vanavälja", "49222")
    p.village("Praaklima", "49227")
    p.village("Varbevere", "49223")
    p.village("Änkküla", "49225")
    p.village("Kaarepere", "49201")
    p.village("Vaidavere", "49221")
    p.village("Luua", "49203")
    p.village("Rahivere", "49216")
    p.village("Toovere", "49220")
    p.village("Nava", "49212")
    p.village("Kivimäe", "49209")
    p.village("Kassivere", "49208")
    p.village("Raadivere", "49228")

    p.municipality("Puurmani", "")
    p.village("Tammiku", "49012")
    p.village("Härjanurme", "49003")
    p.village("Pikknurme", "49009")
    p.village("Jõune", "49004")
    p.village("Jüriküla", "49005")
    p.village("Kirikuvalla", "49006")
    p.village("Altnurga", "49002")
    p.village("Tõrve", "49013")
    p.village("Saduküla", "49011")
    p.village("Kursi", "49007")
    p.village("Laasme", "49008")
    p.village("Pööra", "49010")

    p.municipality("Saare", "")
    p.village("Voore", "")
    p.village("Koseveski", "")
    p.village("Sirguvere", "49317")
    p.village("Vassevere", "49321")
    p.village("Putu", "49313")
    p.village("Pedassaare", "49312")
    p.village("Odivere", "49311")
    p.village("Vanassaare", "49320")
    p.village("Ruskavere", "49315")
    p.village("Saarjärve", "49316")
    p.village("Nautrasi", "49310")
    p.village("Kiisli", "49306")
    p.village("Kallivere", "49305")
    p.village("Halliku", "49303")
    p.village("Maardla", "49309")
    p.village("Veia", "49322")
    p.village("Tarakvere", "49318")
    p.village("Pällu", "49314")
    p.village("Levala", "49308")
    p.village("Jaama", "49304")
    p.village("Kääpa", "49323")
    p.village("Tuulavere", "49319")

    p.municipality("Kasepää", "")
    p.village("Tiheda", "")
    p.village("Raja", "")
    p.village("Kükita", "")
    p.village("Metsaküla", "49505")
    p.village("Omedu", "49507")
    p.village("Nõmme", "49506")
    p.village("Kaasiku", "49502")

    p.municipality("Pajusi", "")
    p.village("Vägari", "")
    p.village("Pisisaare", "")
    p.village("Kalana", "")
    p.village("Lahavere", "")
    p.village("Tapiku", "48218")
    p.village("Kõpu", "48208")
    p.village("Loopre", "48211")
    p.village("Uuevälja", "48220")
    p.village("Tõivere", "48219")
    p.village("Kauru", "48206")
    p.village("Nurga", "48215")
    p.village("Aidu", "48202")
    p.village("Mõisaküla", "48213")
    p.village("Kõrkküla", "48209")
    p.village("Väljataguse", "48223")
    p.village("Kose", "48207")
    p.village("Arisvere", "48203")
    p.village("Kaave", "48204")
    p.village("Vorsti", "48221")
    p.village("Luige", "48212")
    p.village("Mõrtsi", "48214")
    p.village("Sopimetsa", "48217")

    p.municipality("Pala", "")
    p.village("Kodavere", "49407")
    p.village("Haavakivi", "49404")
    p.village("Lümati", "49425")
    p.village("Kokanurga", "49408")
    p.village("Nõva", "49411")
    p.village("Sassukvere", "49418")
    p.village("Kadrina", "49405")
    p.village("Sõõru", "49419")
    p.village("Sääritsa", "49420")
    p.village("Vea", "49422")
    p.village("Ranna", "49417")
    p.village("Perametsa", "49412")
    p.village("Raatvere", "49416")
    p.village("Äteniidi", "49423")
    p.village("Tagumaa", "49421")
    p.village("Kirtsi", "49406")
    p.village("Piibumäe", "49413")
    p.village("Piirivarbe", "49414")
    p.village("Moku", "49410")
    p.village("Assikvere", "49403")
    p.village("Metsanurga", "49409")
    p.village("Punikvere", "49415")

    p.municipality("Vägeva", "")




from setuptools import setup

SETUP_INFO = dict(
    name='commondata.ee',
    version='0.0.1',
    install_requires=['commondata'],
    description="Common data about Estonia",
    license='GPL',
    test_suite='tests',
    author='Luc Saffre',
    author_email='luc.saffre@gmail.com',
    url="http://commondata.lino-framework.org",
    classifiers="""\
Programming Language :: Python
Programming Language :: Python :: 2.6
Programming Language :: Python :: 2.7
Development Status :: 4 - Beta
Intended Audience :: Developers
License :: OSI Approved :: GNU General Public License (GPL)
Natural Language :: English
Operating System :: OS Independent""".splitlines())

SETUP_INFO.update(long_description=file('README.rst').read())

SETUP_INFO.update(packages=[str(n) for n in """
commondata.ee
""".splitlines() if n])

SETUP_INFO.update(namespace_packages=['commondata'])

if __name__ == '__main__':
    setup(**SETUP_INFO)



# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Valga (county)
    p.county("Valga", "")
    p.town("Valga", "")
    p.town("Tõrva", "")
    p.town("Otepää", "")
    p.village("Nüpli", "")
    p.village("Sihva", "")
    p.village("Pühajärve", "")
    p.village("Vidrike", "67304")
    p.village("Pedajamäe", "67417")
    p.village("Tõutsi", "67303")
    p.village("Kääriku", "67309")
    p.village("Mägestiku", "67310")
    p.village("Pilkuse", "67416")
    p.village("Kastolatsi", "67410")
    p.village("Truuta", "67302")
    p.village("Kaurutootsi", "67307")
    p.village("Raudsepa", "67415")
    p.village("Arula", "67411")
    p.village("Mäha", "67409")
    p.village("Kassiratta", "67306")
    p.village("Koigu", "67308")
    p.village("Vana-Otepää", "67418")
    p.village("Märdi", "67311")
    p.village("Ilmjärve", "67305")

    p.municipality("Puka", "")
    p.village("Rebaste", "67216")
    p.village("Aakre", "67212")
    p.village("Palamuste", "67213")
    p.village("Pühaste", "67215")
    p.village("Pedaste", "67214")
    p.village("Põru", "67210")
    p.village("Prange", "67209")
    p.village("Purtsi", "68709")
    p.village("Meegaste", "67207")
    p.village("Kolli", "67204")
    p.village("Kibena", "67203")
    p.village("Vaardi", "68229")
    p.village("Kuigatsi", "68222")
    p.village("Kähri", "67206")
    p.village("Plika", "67208")
    p.village("Soontaga", "68617")
    p.village("Ruuna", "67211")
    p.village("Komsi", "67205")

    p.municipality("Õru", "")
    p.village("Õlatu", "67108")
    p.village("Õruste", "67111")
    p.village("Priipalu", "67102")
    p.village("Mustumetsa", "67106")
    p.village("Killinge", "67103")
    p.village("Lota", "67105")
    p.village("Kiviküla", "67104")
    p.village("Uniküla", "67107")

    p.municipality("Tõlliste", "")
    p.smallborough("Tsirguliina", "")
    p.village("Sooru", "")
    p.smallborough("Laatre", "")
    p.village("Jaanikese", "")
    p.village("Tagula", "")
    p.village("Vilaski", "68311")
    p.village("Rampe", "68310")
    p.village("Muhkva", "68309")
    p.village("Paju", "68217")
    p.village("Korijärve", "68313")
    p.village("Iigaste", "68308")
    p.village("Tinu", "68306")
    p.village("Supa", "68305")
    p.village("Väljaküla", "68312")

    p.municipality("Sangaste", "")
    p.village("Keeni", "")
    p.village("Lossiküla", "")
    p.village("Sarapuu", "67009")
    p.village("Vaalu", "68221")
    p.village("Lauküla", "67011")
    p.village("Tiidu", "67010")
    p.village("Kurevere", "67004")
    p.village("Mäeküla", "67003")
    p.village("Risttee", "67007")
    p.village("Mägiste", "68224")
    p.village("Restu", "67006")
    p.village("Ädu", "68219")
    p.village("Pringi", "68223")

    p.municipality("Karula", "")
    p.village("Raavitsa", "")
    p.village("Kaagjärve", "")
    p.village("Valtina", "")
    p.village("Lüllemäe", "")
    p.village("Koobassaare", "68111")
    p.village("Kirbu", "68107")
    p.village("Väheru", "68105")
    p.village("Pikkjärve", "68110")
    p.village("Rebasemõisa", "68113")
    p.village("Pugritsa", "68104")
    p.village("Londi", "68103")
    p.village("Käärikmäe", "68108")
    p.village("Lusti", "68109")

    p.municipality("Helme", "")
    p.village("Taagepera", "")
    p.village("Karjatnurme", "68511")
    p.village("Koorküla", "68508")
    p.village("Linna", "68619")
    p.village("Kirikuküla", "68611")
    p.village("Jõgeveste", "68616")
    p.village("Möldre", "68612")
    p.village("Holdre", "68505")
    p.village("Pilpa", "68504")
    p.village("Roobe", "68614")
    p.village("Patküla", "68613")
    p.village("Ala", "68507")
    p.village("Kalme", "68618")
    p.village("Kähu", "68506")

    p.municipality("Taheva", "")
    p.village("Koikküla", "")
    p.village("Hargla", "")
    p.village("Lutsu", "68005")
    p.village("Lepa", "68004")
    p.village("Sooblase", "68011")
    p.village("Tõrvase", "68008")
    p.village("Tsirgumäe", "68012")
    p.village("Korkuna", "68009")
    p.village("Koiva", "68006")
    p.village("Kalliküla", "68007")
    p.village("Laanemetsa", "68013")
    p.village("Ringiste", "68010")

    p.municipality("Põdrala", "")
    p.village("Leebiku", "")
    p.village("Riidaja", "")
    p.village("Pikasilla", "68715")
    p.village("Liva", "68706")
    p.village("Rulli", "68615")
    p.village("Uralaane", "68712")
    p.village("Lõve", "68707")
    p.village("Kungi", "68705")
    p.village("Karu", "68703")
    p.village("Vanamõisa", "68713")
    p.village("Kaubi", "68704")
    p.village("Pori", "68708")
    p.village("Voorbahi", "68714")
    p.village("Reti", "68710")

    p.municipality("Palupera", "")
    p.village("Hellenurme", "")
    p.village("Nõuni", "")
    p.village("Mäelooga", "67510")
    p.village("Atra", "67508")
    p.village("Räbi", "67503")
    p.village("Urmi", "67513")
    p.village("Päidla", "67506")
    p.village("Miti", "67509")
    p.village("Pastaku", "67512")
    p.village("Makita", "67516")
    p.village("Astuvere", "67507")
    p.village("Neeruti", "67505")
    p.village("Lutike", "67504")

    p.municipality("Hummuli", "")
    p.village("Piiri", "68405")
    p.village("Ransi", "68407")
    p.village("Kulli", "68404")
    p.village("Aitsra", "68402")
    p.village("Jeti", "68513")
    p.village("Soe", "68408")
    p.village("Puide", "68411")
    p.village("Alamõisa", "68403")





# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Hiiu (county)
    p.county("Hiiu", "")
    p.town("Kärdla", "")
    p.municipality("Käina", "")
    p.village("Nõmme", "")
    p.village("Selja", "")
    p.village("Putkaste", "")
    p.village("Lelu", "")
    p.village("Ligema", "")
    p.village("Ühtri", "")
    p.village("Niidiküla", "92131")
    p.village("Kaigutsi", "92164")
    p.village("Ristivälja", "92135")
    p.village("Nasva", "92130")
    p.village("Mäeküla", "92116")
    p.village("Vaemla", "92137")
    p.village("Mäeltse", "92129")
    p.village("Orjaku", "")
    p.village("Kolga", "92126")
    p.village("Taterma", "92174")
    p.village("Kogri", "92125")
    p.village("Moka", "92128")
    p.village("Aadma", "92161")
    p.village("Taguküla", "92112")
    p.village("Jõeküla", "92118")
    p.village("Kuriste", "92171")
    p.village("Utu", "92136")
    p.village("Kaasiku", "92123")
    p.village("Esiküla", "92113")
    p.village("Laheküla", "92115")
    p.village("Luguse", "92127")
    p.village("Kleemu", "92124")
    p.village("Kassari", "92111")
    p.village("Villemi", "92138")
    p.village("Männamaa", "92102")
    p.village("Pärnselja", "92162")
    p.village("Nõmmerga", "92133")
    p.village("Allika", "92122")

    p.municipality("Kõrgessaare", "")
    p.village("Tahkuna", "")
    p.village("Lauka", "")
    p.village("Ülendi", "92229")
    p.village("Risti", "92224")
    p.village("Metsaküla", "92249")
    p.village("Kidaste", "92216")
    p.village("Kiduspe", "92234")
    p.village("Hüti", "92243")
    p.village("Heigi", "92241")
    p.village("Kopa", "92255")
    p.village("Laasi", "92231")
    p.village("Poama", "92259")
    p.village("Kodeste", "92217")
    p.village("Mangu", "92220")
    p.village("Mudaste", "92222")
    p.village("Hirmuste", "92228")
    p.village("Kalana", "92230")
    p.village("Mardihansu", "92256")
    p.village("Ogandi", "92223")
    p.village("Vilima", "92237")
    p.village("Sülluste", "92252")
    p.village("Puski", "92260")
    p.village("Lilbi", "92248")
    p.village("Koidma", "92218")
    p.village("Kurisu", "")
    p.village("Pihla", "92264")
    p.village("Kaleste", "92232")
    p.village("Kiivera", "92254")
    p.village("Heistesoo", "92270")
    p.village("Kauste", "92215")
    p.village("Reigi", "92265")
    p.village("Sigala", "92213")
    p.village("Tiharu", "92269")
    p.village("Palli", "92258")
    p.village("Lehtma", "92219")
    p.village("Isabella", "92244")
    p.village("Napi", "92250")
    p.village("Mägipe", "92233")
    p.village("Villamaa", "92261")
    p.village("Meelste", "92221")
    p.village("Viita", "92227")
    p.village("Ojaküla", "92235")
    p.village("Viitasoo", "92238")
    p.village("Malvaste", "92211")
    p.village("Suurepsi", "92236")
    p.village("Heiste", "92242")
    p.village("Suureranna", "92225")
    p.village("Leigri", "92247")
    p.village("Luidja", "92202")
    p.village("Rootsi", "92266")
    p.village("Jõeranna", "92263")
    p.village("Paope", "92267")
    p.village("Kõpu", "92212")
    p.village("Jõesuu", "92253")
    p.village("Kanapeeksi", "92214")
    p.village("Otste", "92251")
    p.village("Tammistu", "92268")

    p.municipality("Pühalepa", "")
    p.village("Hausma", "")
    p.village("Suuremõisa", "")
    p.village("Kuri", "")
    p.village("Loja", "")
    p.village("Tareste", "")
    p.village("Hiiessaare", "")
    p.village("Salinõmme", "92317")
    p.village("Sarve", "92322")
    p.village("Lõbembe", "92340")
    p.village("Reikama", "92344")
    p.village("Harju", "")
    p.village("Hagaste", "92332")
    p.village("Kerema", "92315")
    p.village("Lõpe", "92341")
    p.village("Määvli", "92362")
    p.village("Suuresadama", "92346")
    p.village("Partsi", "92342")
    p.village("Soonlepa", "92323")
    p.village("Tubala", "92311")
    p.village("Viilupi", "92320")
    p.village("Valipe", "92319")
    p.village("Värssu", "92349")
    p.village("Kalgi", "92314")
    p.village("Leerimetsa", "92361")
    p.village("Pilpaküla", "92368")
    p.village("Ala", "92331")
    p.village("Prählamäe", "92364")
    p.village("Vilivalla", "92367")
    p.village("Linnumäe", "92422")
    p.village("Sakla", "92345")
    p.village("Vahtrepa", "92318")
    p.village("Undama", "92366")
    p.village("Kõlunõmme", "92338")
    p.village("Aruküla", "92321")
    p.village("Sääre", "92347")
    p.village("Hilleste", "92313")
    p.village("Nõmba", "92363")
    p.village("Hellamaa", "92334")
    p.village("Paluküla", "92420")
    p.village("Palade", "92301")
    p.village("Kukka", "92336")
    p.village("Puliste", "92343")
    p.village("Tempa", "92348")
    p.village("Heltermaa", "92312")
    p.village("Tammela", "92365")

    p.municipality("Emmaste", "")
    p.village("Kaderna", "92045")
    p.village("Reheselja", "92019")
    p.village("Lepiku", "92014")
    p.village("Lassi", "92051")
    p.village("Hindu", "92012")
    p.village("Jausa", "92003")
    p.village("Õngu", "92059")
    p.village("Valgu", "92011")
    p.village("Muda", "92029")
    p.village("Haldreka", "92043")
    p.village("Kabuna", "92041")
    p.village("Metsapere", "92053")
    p.village("Külaküla", "92049")
    p.village("Tilga", "92024")
    p.village("Tärkma", "92026")
    p.village("Sõru", "92023")
    p.village("Külama", "92021")
    p.village("Sinima", "92058")
    p.village("Pärna", "92017")
    p.village("Prassi", "92016")
    p.village("Nurste", "92002")
    p.village("Prähnu", "92056")
    p.village("Kuusiku", "92048")
    p.village("Mänspe", "92054")
    p.village("Viiri", "92027")
    p.village("Kitsa", "92046")
    p.village("Leisu", "92052")
    p.village("Tohvri", "92025")
    p.village("Rannaküla", "92018")
    p.village("Metsalauka", "92015")
    p.village("Ole", "92055")
    p.village("Ulja", "92030")
    p.village("Laartsa", "92050")
    p.village("Härma", "92044")
    p.village("Kõmmusselja", "92013")
    p.village("Riidaküla", "92020")
    p.village("Haldi", "92042")
    p.village("Sepaste", "92022")
    p.village("Vanamõisa", "92060")


